# Trackers API

## SORT

::: trackers.core.sort.tracker.SORTTracker

## ByteTrack

::: trackers.core.bytetrack.tracker.ByteTrackTracker

## OC-SORT

::: trackers.core.ocsort.tracker.OCSORTTracker

## Utilities

::: trackers.utils.converters.xyxy_to_xcycsr

::: trackers.utils.converters.xcycsr_to_xyxy
